@@ -38,7 +38,7 @@
  * @since      File available since Release 1.5
  */
 
-if ('/usr/obj/ports/pear-Date-1.4.6/fake-armish/var/www/pear/lib' != '@'.'include_path'.'@') {
+if ('@include_path@' != '@'.'include_path'.'@') {
     ini_set('include_path', ini_get('include_path')
             . PATH_SEPARATOR . '.'
     );
